<?php
/**
 * Customizer custom controls
 *
 * @package Business_Center_Pro
 * @since Business Center Pro 2.0.0
 */


if ( ! class_exists( 'WP_Customize_Control' ) ) {
	return null;
}

/**
 * Customize Control for Taxonomy Select.
 *
 * @since Business Center Pro 2.0.0
 *
 * @see WP_Customize_Control
 */
class Business_Center_Pro_Dropdown_Taxonomies_Control extends WP_Customize_Control {

	/**
	 * Control type.
	 *
	 * @access public
	 * @var string
	 */
	public $type = 'dropdown-taxonomies';

	/**
	 * Taxonomy.
	 *
	 * @access public
	 * @var string
	 */
	public $taxonomy = '';

	/**
	 * Taxonomy.
	 *
	 * @access public
	 * @var string
	 */
	public $multiple = false;

	/**
	 * Constructor.
	 *
	 * @since Business Center Pro 2.0.0
	 *
	 * @param WP_Customize_Manager $manager Customizer bootstrap instance.
	 * @param string               $id      Control ID.
	 * @param array                $args    Optional. Arguments to override class property defaults.
	 */
	public function __construct( $manager, $id, $args = array() ) {

		$taxonomy = 'category';
		if ( isset( $args['taxonomy'] ) ) {
			$taxonomy_exist = taxonomy_exists( esc_attr( $args['taxonomy'] ) );
			if ( true === $taxonomy_exist ) {
				$taxonomy = esc_attr( $args['taxonomy'] );
			}
		}
		$args['taxonomy'] = $taxonomy;
		$this->taxonomy = esc_attr( $taxonomy );

		parent::__construct( $manager, $id, $args );
	}

	/**
	 * Render content.
	 *
	 * @since Business Center Pro 2.0.0
	 */
	public function render_content() {

		$tax_args = array(
			'hierarchical' => 0,
			'taxonomy'     => $this->taxonomy,
		);
		$taxonomies = get_categories( $tax_args );

		$multiple = $this->multiple;
		if( $multiple ) {
			$multiple_attr = 'size="10" multiple=""';
		} else {
			$multiple_attr = '';
		}

	?>
    <label>
      <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
      <?php if ( ! empty( $this->description ) ) : ?>
      	<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
      <?php endif; ?>
       <select <?php echo $multiple_attr;?> <?php $this->link(); ?>>
			<?php
			printf( '<option value="%s" %s>%s</option>', '', selected( $this->value(), '', false ), '--None--' );
			?>
			<?php if ( ! empty( $taxonomies ) ) :  ?>
            <?php foreach ( $taxonomies as $key => $tax ) :  ?>
				<?php
				printf( '<option value="%s" %s>%s</option>', esc_attr( $tax->term_id ), selected( $this->value(), $tax->term_id, false ), esc_html( $tax->name ) );
				?>
            <?php endforeach ?>
			<?php endif ?>
       </select>
    </label>
    <?php
	}
}

//Custom control for horizontal line
class Business_Center_Pro_Customize_Horizontal_Line extends WP_Customize_Control {
	public $type = 'hr';

	public function render_content() {
		?>
		<div>
			<hr style="border: 1px dotted #72777c;" />
		</div>
		<?php
	}
}

/**
 * Customize Control for Category Select.
 *
 * @since Business Center Pro 2.0.0
 *
 * @see WP_Customize_Control
 */
class Business_Center_Pro_Dropdown_Category_Control extends WP_Customize_Control {

	/**
	 * Control type.
	 *
	 * @access public
	 * @var string
	 */
	public $type = 'dropdown-categories';

	/**
	 * Category.
	 *
	 * @access public
	 * @var string
	 */
	public $taxonomy = '';

	/**
	 * Constructor.
	 *
	 * @since Business Center Pro 2.0.0
	 *
	 * @param WP_Customize_Manager $manager Customizer bootstrap instance.
	 * @param string               $id      Control ID.
	 * @param array                $args    Optional. Arguments to override class property defaults.
	 */
	public function __construct( $manager, $id, $args = array() ) {

		$taxonomy = 'category';
		if ( isset( $args['taxonomy'] ) ) {
			$taxonomy_exist = taxonomy_exists( esc_attr( $args['taxonomy'] ) );
			if ( true === $taxonomy_exist ) {
				$taxonomy = esc_attr( $args['taxonomy'] );
			}
		}
		$args['taxonomy'] = $taxonomy;
		$this->taxonomy = esc_attr( $taxonomy );

		parent::__construct( $manager, $id, $args );
	}

	/**
	 * Render content.
	 *
	 * @since Business Center Pro 2.0.0
	 */
	public function render_content() {

		$tax_args = array(
			'hierarchical' => 0,
			'taxonomy'     => $this->taxonomy,
		);
		$taxonomies = get_categories( $tax_args );

	?>
    <label>
      <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
      <?php if ( ! empty( $this->description ) ) : ?>
      	<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
      <?php endif; ?>
       <select <?php $this->link(); ?> multiple>
			<?php
			printf( '<option value="%s" %s>%s</option>', '', selected( $this->value(), '', false ), esc_html__( '--None--', 'business-center-pro' ) );
			?>
			<?php if ( ! empty( $taxonomies ) ) :  ?>
            <?php foreach ( $taxonomies as $key => $tax ) :  ?>
				<?php
				printf( '<option value="%s" %s>%s</option>', esc_attr( $tax->term_id ), selected( $this->value(), $tax->term_id, false ), esc_html( $tax->name ) );
				?>
            <?php endforeach ?>
			<?php endif ?>
       </select>
    </label>
    <?php
	}
}

//Custom control for any note, use label as output description
class Business_Center_Pro_Note_Control extends WP_Customize_Control {
	public $type = 'description';

	public function render_content() {
		echo '<h2 class="description">' . $this->label . '</h2>';
	}
}

class Business_Center_Pro_Testimonial_Post_Control extends WP_Customize_Control {
	public $type = 'testimonial-post';
	public $post_type = 'jetpack-testimonial';

	public function render_content() {

	$latest = new WP_Query( array(
		'post_type'   => $this->post_type,
		'post_status' => 'publish',
		'orderby'     => 'date',
		'order'       => 'DESC'
	));

	?>
		<label>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<select <?php $this->link(); ?> multiple style="height: 200px;">
   	   			<option value="null"><?php _e( '&mdash; None &mdash;', 'business-center-pro' ); ?></option>
				<?php
				while( $latest->have_posts() ) {
					$latest->the_post();
					echo "<option " . selected( $this->value(), get_the_ID() ) . " value='" . get_the_ID() . "'>" . the_title( '', '', false ) . "</option>";
				}
				wp_reset_postdata();
				?>
			</select>
		</label>
	<?php
	}
}

/**
 * Customize Control for parent category Select.
 *
 * @since Business Center Pro 2.0.0
 *
 * @see WP_Customize_Control
 */
class Business_Center_Pro_Dropdown_Taxonomy extends WP_Customize_Control {
	/**
	 * Control type.
	 *
	 * @access public
	 * @var string
	 */
	public $type = 'dropdown-custom-taxonomy';

	/**
	 * Category.
	 *
	 * @access public
	 * @var string
	 */
	public $taxonomy = '';

	/**
	 * Constructor.
	 *
	 * @since Business Center Pro 2.0.0
	 *
	 * @param WP_Customize_Manager $manager Customizer bootstrap instance.
	 * @param string               $id      Control ID.
	 * @param array                $args    Optional. Arguments to override class property defaults.
	 */
	public function __construct( $manager, $id, $args = array() ) {

		$taxonomy = get_taxonomies( array( '_builtin' => false ), 'objects');

		$this->taxonomy = $taxonomy;

		parent::__construct( $manager, $id, $args );
	}

	/**
	 * Render content.
	 *
	 * @since Business Center Pro 2.0.0
	 */
	public function render_content() {	?>
    <label>
      <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
      <?php if ( ! empty( $this->description ) ) : ?>
      	<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
      <?php endif; ?>
       <select <?php $this->link(); ?> >
			<?php
			printf( '<option value="%s" %s>%s</option>', '', selected( $this->value(), '', false ), esc_html__( '--None--', 'business-center-pro' ) );
			?>
			<?php if ( ! empty( $this->taxonomy ) ) : ?>
            <?php foreach ( $this->taxonomy as $tax ) :  ?>
				<?php
				printf( '<option value="%s" %s>%s</option>', esc_attr( $tax->name ), selected( $this->value(), $tax->name, false ), esc_html( $tax->name ) );
				?>
            <?php endforeach ?>
			<?php endif ?>
       </select>
    </label>
    <?php
	}
}

/**
 * Multiple checkbox customize control class.
 *
 * @since  1.0.0
 * @access public
 */
class Business_Center_Pro_Customize_Control_Checkbox_Multiple extends WP_Customize_Control {

    /**
     * The type of customize control being rendered.
     *
     * @since  1.0.0
     * @access public
     * @var    string
     */
    public $type = 'checkbox-multiple';

    /**
	 * Taxonomy.
	 *
	 * @access public
	 * @var string
	 */
	public $taxonomy = '';

    /**
     * Enqueue scripts/styles.
     *
     * @since  1.0.0
     * @access public
     * @return void
     */
    public function enqueue() {
        wp_enqueue_script( 'business-center-pro-customize-controls', get_template_directory_uri() . '/assets/js/customize-control.min.js', array( 'customize-controls' ) );
    }

    /**
     * Constructor.
     *
     * @since Business Center Pro 2.0.0
     *
     * @param WP_Customize_Manager $manager Customizer bootstrap instance.
     * @param string               $id      Control ID.
     * @param array                $args    Optional. Arguments to override class property defaults.
     */
    public function __construct( $manager, $id, $args = array() ) {

    	$taxonomy = 'category';
    	if ( isset( $args['taxonomy'] ) ) {
    		$taxonomy_exist = taxonomy_exists( esc_attr( $args['taxonomy'] ) );
    		if ( true === $taxonomy_exist ) {
    			$taxonomy = esc_attr( $args['taxonomy'] );
    		}
    	}
    	$args['taxonomy'] = $taxonomy;
    	$this->taxonomy = esc_attr( $taxonomy );

    	parent::__construct( $manager, $id, $args );
    }

    /**
     * Displays the control content.
     *
     * @since  1.0.0
     * @access public
     * @return void
     */
    public function render_content() {

    	$tax_args = array(
    		'hierarchical' => 0,
    		'taxonomy'     => $this->taxonomy,
    	);

    	$choices = get_categories( $tax_args );

        if ( empty( $choices ) )
            return; ?>

        <?php if ( !empty( $this->label ) ) : ?>
            <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
        <?php endif; ?>

        <?php if ( !empty( $this->description ) ) : ?>
            <span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
        <?php endif; ?>

        <?php $multi_values = !is_array( $this->value() ) ? explode( ',', $this->value() ) : $this->value(); ?>

        <ul style="height: 150px; overflow-y: scroll">
            <?php foreach ( $choices as $value ) :
            $value_arr = ! empty(  $this->value() ) ? $this->value() : array();
            ?>
                <li>
                    <label>
                        <input type="checkbox" value="<?php echo esc_attr( $value->term_id ); ?>" <?php checked( in_array( $value->term_id, $value_arr ) ); ?> />
                        <?php echo esc_html( $value->name ); ?>
                    </label>
                </li>
            <?php endforeach; ?>
        </ul>

        <input type="hidden" <?php $this->link(); ?> value="<?php echo esc_attr( implode( ',', $multi_values ) ); ?>" />
    <?php }
}

/**
 * Posts drop down on the basis of post types control class.
 *
 * @since  1.0.0
 * @access public
 */
class WP_Customize_Post_Drop_Down_Control extends WP_Customize_Control {

		/**
		 * Control type.
		 *
		 * @access public
		 * @var string
		 */
		public $type = 'post-dropdown';

	    /**
		 * Post type.
		 *
		 * @access public
		 * @var string
		 */
		public $post_type = '';

		public function render_content() {

			$query = new WP_Query( array(
				'post_type'   => $this->post_type,
				'post_status' => 'publish',
				'orderby'     => 'date',
				'order'       => 'DESC'
			));

			?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<select <?php $this->link(); ?>>
						<?php
						while( $query->have_posts() ) {
							$query->the_post();
							echo "<option " . selected( $this->value(), get_the_ID() ) . " value='" . get_the_ID() . "'>" . the_title( '', '', false ) . "</option>";
						}
						?>
					</select>
				</label>
			<?php
		}
	}